//
//  NSFileManagerAdditions.h
//  AraeliumFoundation
//
//  Created by Seth Willits on 3/22/05.
//  Copyright 2005 Araelium Group. All rights reserved.
//

#import <Cocoa/Cocoa.h>
#import <Foundation/Foundation.h>
#import <Security/Security.h>


@interface NSFileManager (AraeliumFolderSizeAdditions)

enum { 
	AGFolderLogicalSize		= 1 << 0,
	AGFolderPhysicalSize	= 1 << 2,
	AGFolderDataFork		= 1 << 3,
	AGFolderResourceFork	= 1 << 4,
	AGFolderSizeDefaultOptions = (AGFolderDataFork | AGFolderResourceFork | AGFolderLogicalSize)
};

- (uint64_t)sizeOfFolderAtPath:(NSString *)path options:(NSUInteger)options;

@end



@interface NSFileManager (AraeliumAdditions)
- (NSString *)findSystemFolderType:(NSInteger)folderType forDomain:(NSInteger)domain;
- (NSString *)fileTypeForFileAtPath:(NSString *)filePath;
- (NSString *)uniquePathForFileWithDesiredPath:(NSString *)inPath;
- (NSString *)pathForDuplicateOfFileAtPath:(NSString *)path;
- (NSString *)duplicateFileAtPath:(NSString *)path handler:(id)handler;
- (BOOL)createAllDirectoriesForPath:(NSString *)path attributes:(NSDictionary *)attributes;
- (BOOL)moveContentsOfDirectoryAtPath:(NSString *)sourceDirectoryPath intoDirectoryAtPath:(NSString *)destinationDirectoryPath replace:(BOOL)replace;
- (BOOL)removeDirectoryAtPath:(NSString *)directoryPath;
@end


@interface NSFileManager (AraeliumAdditionsWithAuthorization)

// Do multiple ops under a single authorization
- (OSStatus)obtainAuthorization:(AuthorizationRef *)outAuthorizationRef flags:(AuthorizationFlags)flags;
- (void)freeAuthorization:(AuthorizationRef)authorizationRef;
- (OSStatus)removeFileAtPath:(NSString *)sourcePath removeDirectories:(BOOL)directories recursive:(BOOL)recursive withAuthorization:(AuthorizationRef)authorizationRef;
- (OSStatus)copyPath:(NSString *)sourcePath toPath:(NSString *)destinationPath replace:(BOOL)replace withAuthorization:(AuthorizationRef)authorizationRef;
- (OSStatus)movePath:(NSString *)sourcePath toPath:(NSString *)destinationPath replace:(BOOL)replace withAuthorization:(AuthorizationRef)authorizationRef;
- (OSStatus)moveContentsOfDirectoryAtPath:(NSString *)sourceDirPath intoDirectoryAtPath:(NSString *)destDirPath replace:(BOOL)replace withAuthorization:(AuthorizationRef)authorizationRef;

// Do discrete auths for each operation
- (OSStatus)authorizedRemoveFileAtPath:(NSString *)sourcePath removeDirectories:(BOOL)directories recursive:(BOOL)recursive;
- (OSStatus)authorizedCopyPath:(NSString *)sourcePath toPath:(NSString *)destinationPath replace:(BOOL)replace;
- (OSStatus)authorizedMovePath:(NSString *)sourcePath toPath:(NSString *)destinationPath replace:(BOOL)replace;
- (OSStatus)authorizedMoveContentsOfDirectoryAtPath:(NSString *)sourceDirPath intoDirectoryAtPath:(NSString *)destDirPath replace:(BOOL)replace;

@end


